---
title: <span class="badge builder"></span> ConnectionCoordinates
---
# <span class="badge builder"></span> ConnectionCoordinates

## Constructor

```python
ConnectionCoordinates()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> canvas.ConnectionCoordinates
```

### <span class="badge object-method"></span> x

```python
def x(x: float) -> typing.Self
```

### <span class="badge object-method"></span> y

```python
def y(y: float) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ConnectionCoordinates](./object-ConnectionCoordinates.md)
